@@ -43,6 +43,7 @@
 #include "gossip-utils.h"
 #include "gossip-group-chat.h"
 #include "gossip-chat.h"
+#include "gossip-private-chat.h"
 #include "gossip-account.h"
 #include "gossip-connect-dialog.h"
 #include "gossip-join-dialog.h"
@@ -51,6 +52,7 @@
 #include "gossip-startup-druid.h"
 #include "gossip-preferences.h"
 #include "gossip-presence.h"
+#include "gossip-private-chat.h"
 #include "gossip-account-dialog.h"
 #include "gossip-stock.h"
 #include "gossip-roster-view.h"
@@ -439,11 +441,11 @@ app_init (GossipApp *singleton_app)
 	priv->roster_view = gossip_roster_view_new (priv->roster);
 
 	show_offline = gconf_client_get_bool (gconf_client,
-					      "/apps/gossip/contact/show_offline",
+					      "/apps/gossip/contacts/show_offline",
 					      NULL);
 
 	gconf_client_notify_add (gconf_client,
-				 "/apps/gossip/contact/show_offline",
+				 "/apps/gossip/contacts/show_offline",
 				 app_show_offline_key_changed_cb,
 				 show_offline_widget,
 				 NULL, NULL);
@@ -867,7 +869,7 @@ app_show_offline_cb (GtkCheckMenuItem *item, GossipApp *app)
 	current = gtk_check_menu_item_get_active (item);
 
 	gconf_client_set_bool (gconf_client,
-			       "/apps/gossip/contact/show_offline",
+			       "/apps/gossip/contacts/show_offline",
 			       current,
 			       NULL);
 
@@ -1066,7 +1068,7 @@ app_message_handler (LmMessageHandler *handler,
 	case LM_MESSAGE_SUB_TYPE_CHAT:
 	case LM_MESSAGE_SUB_TYPE_HEADLINE: /* For now, fixes #120009 */
 		app_tray_push_message (m);
-		return gossip_chat_handle_message (m);
+		return gossip_private_chat_handle_message (m);
 
 	case LM_MESSAGE_SUB_TYPE_GROUPCHAT:
 		g_warning ("Hmm .. looks like an unhandled group chat message "
@@ -1128,7 +1130,11 @@ app_iq_handler (LmMessageHandler *handler,
 			      LM_HANDLER_RESULT_ALLOW_MORE_HANDLERS);
 	g_return_val_if_fail (GOSSIP_IS_APP (app),
 			      LM_HANDLER_RESULT_ALLOW_MORE_HANDLERS);
-	
+
+        if (lm_message_get_sub_type (m) != LM_MESSAGE_SUB_TYPE_GET) {
+                return LM_HANDLER_RESULT_ALLOW_MORE_HANDLERS;
+        }
+        
 	node = lm_message_node_get_child (m->node, "query");
 
 	if (node) {
@@ -1279,10 +1285,10 @@ app_contact_activated_cb (GossipRosterView *roster,
 			  GossipContact    *contact,
 			  GossipApp        *app)
 {
-	GossipChat *chat;
+	GossipPrivateChat *chat;
 
-	chat = gossip_chat_get_for_contact (contact, TRUE);
-	gossip_chat_present (chat);
+	chat = gossip_private_chat_get_for_contact (contact, TRUE);
+	gossip_chat_present (GOSSIP_CHAT (chat));
 
 	app_tray_pop_message (contact);
 }
@@ -1384,6 +1390,24 @@ gossip_app_connect (void)
 	if (!priv->account) {
 		return;
 	}
+
+	if (priv->account->use_proxy) {
+		gossip_utils_set_proxy (priv->connection);
+	} else {
+		LmProxy *proxy;
+		proxy = lm_proxy_new (LM_PROXY_TYPE_NONE);
+		lm_connection_set_proxy (priv->connection, proxy);
+		lm_proxy_unref (proxy);
+	}
+
+	if (priv->account->use_proxy) {
+		gossip_utils_set_proxy (priv->connection);
+	} else {
+		LmProxy *proxy;
+		proxy = lm_proxy_new (LM_PROXY_TYPE_NONE);
+		lm_connection_set_proxy (priv->connection, proxy);
+		lm_proxy_unref (proxy);
+	}
 	
 	app_disconnect ();
 	
@@ -1404,7 +1428,17 @@ gossip_app_connect (void)
 		lm_connection_set_ssl (priv->connection, ssl);
 		lm_ssl_unref (ssl);
 	}
-	
+
+	if (priv->account->use_proxy) {
+		gossip_utils_set_proxy (priv->connection);
+	} else {
+		/* FIXME: Just pass NULL when Loudmouth > 0.17.1 */
+		LmProxy *proxy;
+		proxy = lm_proxy_new (LM_PROXY_TYPE_NONE);
+		lm_connection_set_proxy (priv->connection, proxy);
+		lm_proxy_unref (proxy);
+	}
+
 	result = lm_connection_open (priv->connection,
 				     (LmResultFunction) app_connection_open_cb,
 				     app, NULL, &error);
@@ -1474,7 +1508,6 @@ app_create_connection (void)
 	// Setup the connection to send keep alive messages every 30 second.
 	lm_connection_set_keep_alive_rate (priv->connection, 30);
 
-	gossip_utils_set_proxy (priv->connection);
 	lm_connection_set_jid (priv->connection, gossip_jid_get_without_resource (priv->account->jid));
 
 	lm_connection_set_port (priv->connection, priv->account->port);
@@ -1584,9 +1617,9 @@ app_complete_name_response_cb (GtkWidget        *dialog,
 			       gint              response,
 			       CompleteNameData *data)
 {
-	const gchar *str;
-	GossipChat  *chat;
-	GList       *l;
+	const gchar        *str;
+	GossipPrivateChat  *chat;
+	GList              *l;
 
 	if (response == GTK_RESPONSE_OK) {
 		GossipRosterItem *item;
@@ -1604,9 +1637,9 @@ app_complete_name_response_cb (GtkWidget        *dialog,
 
 			contact = gossip_roster_get_contact_from_item (gossip_app_get_roster (),
 							       item);
-			chat = gossip_chat_get_for_contact (contact, TRUE);
+			chat = gossip_private_chat_get_for_contact (contact, TRUE);
 			
-			gossip_chat_present (chat);
+			gossip_chat_present (GOSSIP_CHAT (chat));
 		}
 	}
 
@@ -1972,9 +2005,9 @@ app_tray_push_message (LmMessage *m)
 static gboolean
 app_tray_pop_message (GossipContact *contact)
 {
-	GossipAppPriv *priv;
-	GossipChat    *chat;
-	GList         *l;
+	GossipAppPriv     *priv;
+	GossipPrivateChat *chat;
+	GList             *l;
 
 	priv = app->priv;
 
@@ -1986,12 +2019,12 @@ app_tray_pop_message (GossipContact *contact)
 		contact = priv->tray_flash_icons->data;
 	}
 	
-	chat = gossip_chat_get_for_contact (contact, TRUE);
+	chat = gossip_private_chat_get_for_contact (contact, TRUE);
 	if (!chat) {
 		return FALSE;
 	}
 
-	gossip_chat_present (chat);
+	gossip_chat_present (GOSSIP_CHAT (chat));
 
 	l = g_list_find_custom (priv->tray_flash_icons, contact,
 				(GCompareFunc) gossip_contact_compare);
